Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::variant< Ts > Member List

This is the complete list of members for ranges::v3::variant< Ts >, including all inherited members.

detail::variant_base< variant, false > (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > | friend
detail::variant_core_access (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > | friend
emplace(Args &&...args) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index() const (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index_(N) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index_(N) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index_(N) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index_(detail::variant_move_copy_(that.index(), data_(), detail::move(that.data_()))) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
index_(detail::variant_move_copy_(that.index(), data_(), that.data_())) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
operator=(variant &&that) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
operator=(variant const &that) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
size() (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > | static
valid() const (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > | friend
variant() (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant(RANGES_EMPLACED_INDEX_T(N), Args &&...args) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant(RANGES_EMPLACED_INDEX_T(N), std::initializer_list< T > il) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant(RANGES_EMPLACED_INDEX_T(N), meta::nil_) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant(variant &&that) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
variant(variant const &that) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
visit(Fun fun) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
visit(Fun fun) const (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
visit_i(Fun fun) (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |
visit_i(Fun fun) const (defined in ranges::v3::variant< Ts >) | ranges::v3::variant< Ts > |